==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/databoxedge/kotlin/UserArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.databoxedge.kotlin

import com.pulumi.azurenative.databoxedge.UserArgs.builder
import com.pulumi.azurenative.databoxedge.kotlin.enums.UserType
import com.pulumi.azurenative.databoxedge.kotlin.inputs.AsymmetricEncryptedSecretArgs
import com.pulumi.azurenative.databoxedge.kotlin.inputs.AsymmetricEncryptedSecretArgsBuilder
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Represents a user who has access to one or more shares on the Data Box Edge/Gateway device.
 * Azure REST API version: 2022-03-01. Prior API version in Azure Native 1.x: 2020-12-01.
 * Other available API versions: 2019-07-01, 2019-08-01, 2021-02-01-preview, 2023-01-01-preview, 2023-07-01.
 * ## Example Usage
 * ### UserPut
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var user = new AzureNative.DataBoxEdge.User("user", new()
 *     {
 *         DeviceName = "testedgedevice",
 *         EncryptedPassword = new AzureNative.DataBoxEdge.Inputs.AsymmetricEncryptedSecretArgs
 *         {
 *             EncryptionAlgorithm = "None",
 *             EncryptionCertThumbprint = "blah",
 *             Value = "<value>",
 *         },
 *         Name = "user1",
 *         ResourceGroupName = "GroupForEdgeAutomation",
 *         UserType = "Share",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/databoxedge/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := databoxedge.NewUser(ctx, "user", &databoxedge.UserArgs{
 * 			DeviceName: pulumi.String("testedgedevice"),
 * 			EncryptedPassword: &databoxedge.AsymmetricEncryptedSecretArgs{
 * 				EncryptionAlgorithm:      pulumi.String("None"),
 * 				EncryptionCertThumbprint: pulumi.String("blah"),
 * 				Value:                    pulumi.String("<value>"),
 * 			},
 * 			Name:              pulumi.String("user1"),
 * 			ResourceGroupName: pulumi.String("GroupForEdgeAutomation"),
 * 			UserType:          pulumi.String("Share"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.databoxedge.User;
 * import com.pulumi.azurenative.databoxedge.UserArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var user = new User("user", UserArgs.builder()
 *             .deviceName("testedgedevice")
 *             .encryptedPassword(Map.ofEntries(
 *                 Map.entry("encryptionAlgorithm", "None"),
 *                 Map.entry("encryptionCertThumbprint", "blah"),
 *                 Map.entry("value", "<value>")
 *             ))
 *             .name("user1")
 *             .resourceGroupName("GroupForEdgeAutomation")
 *             .userType("Share")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:databoxedge:User user1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DataBoxEdge/dataBoxEdgeDevices/{deviceName}/users/{name}
 * ```
 * @property deviceName The device name.
 * @property encryptedPassword The password details.
 * @property name The user name.
 * @property resourceGroupName The resource group name.
 * @property userType Type of the user.
 */
public data class UserArgs(
    public val deviceName: Output<String>? = null,
    public val encryptedPassword: Output<AsymmetricEncryptedSecretArgs>? = null,
    public val name: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val userType: Output<Either<String, UserType>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.databoxedge.UserArgs> {
    override fun toJava(): com.pulumi.azurenative.databoxedge.UserArgs =
        com.pulumi.azurenative.databoxedge.UserArgs.builder()
            .deviceName(deviceName?.applyValue({ args0 -> args0 }))
            .encryptedPassword(encryptedPassword?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .name(name?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .userType(
                userType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [UserArgs].
 */
@PulumiTagMarker
public class UserArgsBuilder internal constructor() {
    private var deviceName: Output<String>? = null

    private var encryptedPassword: Output<AsymmetricEncryptedSecretArgs>? = null

    private var name: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    private var userType: Output<Either<String, UserType>>? = null

    /**
     * @param value The device name.
     */
    @JvmName("ssjheadjmvgdvytt")
    public suspend fun deviceName(`value`: Output<String>) {
        this.deviceName = value
    }

    /**
     * @param value The password details.
     */
    @JvmName("ibhcxiwmpurfkylv")
    public suspend fun encryptedPassword(`value`: Output<AsymmetricEncryptedSecretArgs>) {
        this.encryptedPassword = value
    }

    /**
     * @param value The user name.
     */
    @JvmName("nmsxfoqbdmsgnfqb")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The resource group name.
     */
    @JvmName("raknwcwyagyaouws")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value Type of the user.
     */
    @JvmName("mybxjrgyuquqbhld")
    public suspend fun userType(`value`: Output<Either<String, UserType>>) {
        this.userType = value
    }

    /**
     * @param value The device name.
     */
    @JvmName("dieabrijocaxhbnv")
    public suspend fun deviceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deviceName = mapped
    }

    /**
     * @param value The password details.
     */
    @JvmName("dopqdgrvfhqwxvrs")
    public suspend fun encryptedPassword(`value`: AsymmetricEncryptedSecretArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.encryptedPassword = mapped
    }

    /**
     * @param argument The password details.
     */
    @JvmName("ojovxbbpxdpwjhcf")
    public suspend
    fun encryptedPassword(argument: suspend AsymmetricEncryptedSecretArgsBuilder.() -> Unit) {
        val toBeMapped = AsymmetricEncryptedSecretArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.encryptedPassword = mapped
    }

    /**
     * @param value The user name.
     */
    @JvmName("yieyktcubbrsitaf")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The resource group name.
     */
    @JvmName("iijtjgodyqroleaw")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Type of the user.
     */
    @JvmName("erhlpfrqgwtemwrj")
    public suspend fun userType(`value`: Either<String, UserType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userType = mapped
    }

    /**
     * @param value Type of the user.
     */
    @JvmName("ccaporgoweunkbhs")
    public fun userType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, UserType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.userType = mapped
    }

    /**
     * @param value Type of the user.
     */
    @JvmName("crqkbigmolfljphm")
    public fun userType(`value`: UserType) {
        val toBeMapped = Either.ofRight<String, UserType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.userType = mapped
    }

    internal fun build(): UserArgs = UserArgs(
        deviceName = deviceName,
        encryptedPassword = encryptedPassword,
        name = name,
        resourceGroupName = resourceGroupName,
        userType = userType,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/databoxedge/kotlin/UserArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.databoxedge.kotlin

import com.pulumi.azurenative.databoxedge.UserArgs.builder
import com.pulumi.azurenative.databoxedge.kotlin.enums.UserType
import com.pulumi.azurenative.databoxedge.kotlin.inputs.AsymmetricEncryptedSecretArgs
import com.pulumi.azurenative.databoxedge.kotlin.inputs.AsymmetricEncryptedSecretArgsBuilder
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Represents a user who has access to one or more shares on the Data Box Edge/Gateway device.
 * Azure REST API version: 2022-03-01. Prior API version in Azure Native 1.x: 2020-12-01.
 * Other available API versions: 2019-07-01, 2019-08-01, 2021-02-01-preview, 2023-01-01-preview, 2023-07-01, 2023-12-01.
 * ## Example Usage
 * ### UserPut
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var user = new AzureNative.DataBoxEdge.User("user", new()
 *     {
 *         DeviceName = "testedgedevice",
 *         EncryptedPassword = new AzureNative.DataBoxEdge.Inputs.AsymmetricEncryptedSecretArgs
 *         {
 *             EncryptionAlgorithm = "None",
 *             EncryptionCertThumbprint = "blah",
 *             Value = "<value>",
 *         },
 *         Name = "user1",
 *         ResourceGroupName = "GroupForEdgeAutomation",
 *         UserType = "Share",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/databoxedge/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := databoxedge.NewUser(ctx, "user", &databoxedge.UserArgs{
 * 			DeviceName: pulumi.String("testedgedevice"),
 * 			EncryptedPassword: &databoxedge.AsymmetricEncryptedSecretArgs{
 * 				EncryptionAlgorithm:      pulumi.String("None"),
 * 				EncryptionCertThumbprint: pulumi.String("blah"),
 * 				Value:                    pulumi.String("<value>"),
 * 			},
 * 			Name:              pulumi.String("user1"),
 * 			ResourceGroupName: pulumi.String("GroupForEdgeAutomation"),
 * 			UserType:          pulumi.String("Share"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.databoxedge.User;
 * import com.pulumi.azurenative.databoxedge.UserArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var user = new User("user", UserArgs.builder()
 *             .deviceName("testedgedevice")
 *             .encryptedPassword(Map.ofEntries(
 *                 Map.entry("encryptionAlgorithm", "None"),
 *                 Map.entry("encryptionCertThumbprint", "blah"),
 *                 Map.entry("value", "<value>")
 *             ))
 *             .name("user1")
 *             .resourceGroupName("GroupForEdgeAutomation")
 *             .userType("Share")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:databoxedge:User user1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DataBoxEdge/dataBoxEdgeDevices/{deviceName}/users/{name}
 * ```
 * @property deviceName The device name.
 * @property encryptedPassword The password details.
 * @property name The user name.
 * @property resourceGroupName The resource group name.
 * @property userType Type of the user.
 */
public data class UserArgs(
    public val deviceName: Output<String>? = null,
    public val encryptedPassword: Output<AsymmetricEncryptedSecretArgs>? = null,
    public val name: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val userType: Output<Either<String, UserType>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.databoxedge.UserArgs> {
    override fun toJava(): com.pulumi.azurenative.databoxedge.UserArgs =
        com.pulumi.azurenative.databoxedge.UserArgs.builder()
            .deviceName(deviceName?.applyValue({ args0 -> args0 }))
            .encryptedPassword(encryptedPassword?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .name(name?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .userType(
                userType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [UserArgs].
 */
@PulumiTagMarker
public class UserArgsBuilder internal constructor() {
    private var deviceName: Output<String>? = null

    private var encryptedPassword: Output<AsymmetricEncryptedSecretArgs>? = null

    private var name: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    private var userType: Output<Either<String, UserType>>? = null

    /**
     * @param value The device name.
     */
    @JvmName("tndvxgdlqxfygdlu")
    public suspend fun deviceName(`value`: Output<String>) {
        this.deviceName = value
    }

    /**
     * @param value The password details.
     */
    @JvmName("ahqhnrrmrexxagsk")
    public suspend fun encryptedPassword(`value`: Output<AsymmetricEncryptedSecretArgs>) {
        this.encryptedPassword = value
    }

    /**
     * @param value The user name.
     */
    @JvmName("tcajnwkmmpbdtdna")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The resource group name.
     */
    @JvmName("xlmwynxcypmxqvqd")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value Type of the user.
     */
    @JvmName("hvouonghalckfljj")
    public suspend fun userType(`value`: Output<Either<String, UserType>>) {
        this.userType = value
    }

    /**
     * @param value The device name.
     */
    @JvmName("dlbyqtpndylljine")
    public suspend fun deviceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deviceName = mapped
    }

    /**
     * @param value The password details.
     */
    @JvmName("rousyxojrgmujpym")
    public suspend fun encryptedPassword(`value`: AsymmetricEncryptedSecretArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.encryptedPassword = mapped
    }

    /**
     * @param argument The password details.
     */
    @JvmName("sarrhjpanarekead")
    public suspend
    fun encryptedPassword(argument: suspend AsymmetricEncryptedSecretArgsBuilder.() -> Unit) {
        val toBeMapped = AsymmetricEncryptedSecretArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.encryptedPassword = mapped
    }

    /**
     * @param value The user name.
     */
    @JvmName("ngawiuquykbyquht")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The resource group name.
     */
    @JvmName("hqnexmbkhpqsuqie")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Type of the user.
     */
    @JvmName("vjbkrymmctnbvggn")
    public suspend fun userType(`value`: Either<String, UserType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userType = mapped
    }

    /**
     * @param value Type of the user.
     */
    @JvmName("atyyxnfslolwrlyh")
    public fun userType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, UserType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.userType = mapped
    }

    /**
     * @param value Type of the user.
     */
    @JvmName("dtyaqpvmjatymmwf")
    public fun userType(`value`: UserType) {
        val toBeMapped = Either.ofRight<String, UserType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.userType = mapped
    }

    internal fun build(): UserArgs = UserArgs(
        deviceName = deviceName,
        encryptedPassword = encryptedPassword,
        name = name,
        resourceGroupName = resourceGroupName,
        userType = userType,
    )
}
